
#include <stdio.h>
#include "SDL.h"
#include "SDL_mixer.h"

int main (int argc, char **argv )
{
	/* format audio dsir (par exemple...) */
	int audio_rate = 11025;
	Uint16 audio_format = AUDIO_S16; /* 16-bit stereo */
	int audio_channels = 2;
	int audio_buffers = 4096;

	Mix_Music *music = NULL;
        Mix_Chunk *chunk = NULL;
        
	if ( SDL_Init(SDL_INIT_VIDEO | SDL_INIT_AUDIO) < 0 )
	{
        	fprintf(stderr, "Echec d'initialisation de SDL_AUDIO : %s\n", SDL_GetError());
        	return 1;
	}
        
	/* requte du format audio souhait */
	if(Mix_OpenAudio(audio_rate, audio_format, audio_channels, audio_buffers))
	{
		printf("Unable to open audio : %s\n", SDL_GetError());
		SDL_Quit();
		return 1;
	}
        
	/* format audio rellement obtenu (selon les capacits de la carte son)
	 * souvent identique au format souhait */
	Mix_QuerySpec(&audio_rate, &audio_format, &audio_channels);
	printf("Matriel audio acquis.\nspcifications : echantillonage : %li, cannaux : %i, buffer : %i\n", audio_rate, audio_channels, 0);

	/* chargement d'une musique au format mp3, peut egalement charger des ogg, wav, midi, mod */
	music = Mix_LoadMUS("vie_sur_terre.mp3");
	if ( !music )
	{
        	fprintf(stderr, "Echec de chargement du fichier de musique : %s\n", SDL_GetError());
		Mix_CloseAudio();
		SDL_Quit();
	}
        
	/* chargement d'un son (bruitage) */
        chunk = Mix_LoadWAV("k3b_success.wav");
	if ( !chunk )
	{
        	fprintf(stderr, "Echec de chargement du fichier de musique : %s\n", SDL_GetError());
                Mix_FreeMusic(music);
		Mix_CloseAudio();
		SDL_Quit();
	}
	/* rglage du volume pour ce bruitage */
        Mix_VolumeChunk(chunk, 32);
        
	/* creation d'une fenetre pour pouvoir rcuperer les venements du clavier */
        SDL_SetVideoMode( 320, 240, 0, 0 );
        SDL_Event event;
        int channel = -1;
        
        while ( SDL_WaitEvent(&event) )
        {
        	switch (event.type)
                {
                case SDL_QUIT:
			/* on libre tout et on quitte */
		        Mix_FreeMusic(music);
                        music = NULL;
                        Mix_FreeChunk(chunk);
                        chunk = NULL;
			Mix_CloseAudio();
			SDL_Quit();
                	break;
                        
                case SDL_KEYDOWN:
                	switch (event.key.keysym.sym)
                        {
                        case SDLK_ESCAPE:
				/* on libre tout et on quitte */
				Mix_FreeMusic( music );
                                music = NULL;
                        	Mix_FreeChunk(chunk);
                        	chunk = NULL;
				Mix_CloseAudio();
				SDL_Quit();
				break;
                                
                        case SDLK_m:
				/* on joue la musique */
                        	Mix_PlayMusic(music, 0);
                                break;
                                
                        case SDLK_s:
				/* on arete la musique et le bruitage */
                        	Mix_HaltMusic();
                                if ( Mix_Playing(channel) )
                                        Mix_HaltChannel(channel);
                                 break;
                                
                        case SDLK_SPACE:
				/* on arete le bruitage s'il tait en train de jouer
				 * et on le relance */
				if ( Mix_Playing(channel) )
                                	Mix_HaltChannel(channel);
                        	channel = Mix_PlayChannel(-1, chunk, 0);
                                break;
                        }
                	break;
                }
        }
	
	/* on libre sdl mixer et on quitte */
	Mix_CloseAudio();
	SDL_Quit();

	return 0;
}

